@@ -36,6 +36,10 @@ from ubuntu_sso.utils.webclient.common import (
     WebClientError,
 )
 
+try:
+    from urllib.parse import quote
+except ImportError:
+    from urllib import quote
 
 logger = setup_logging('backend')
 
@@ -333,9 +337,8 @@ class ControlBackend(object):
             credentials = yield self.get_credentials()
 
         if credentials:
-            parameters = {'next': iri}
-            iri = yield self.wc.build_signed_iri(UBUNTUONE_FROM_OAUTH,
-                                                 parameters)
+            sign_iri = UBUNTUONE_FROM_OAUTH + '?next=%s' % quote(iri, safe='')
+            iri = yield self.wc.build_signed_iri(sign_iri)
         returnValue(iri)
 
     @inlineCallbacks
