@@ -24,7 +24,7 @@ from ubuntuone.controlpanel.gui.tests import USER_HOME
 from ubuntuone.controlpanel.gui.qt import share_links_search as gui
 from ubuntuone.controlpanel.gui.qt.tests import BaseTestCase
 
-from mock import call, patch
+from mock import patch
 
 # pylint: disable=W0212
 
@@ -175,7 +175,7 @@ class SearchBoxTestCase(BaseTestCase):
 
 
 class SearchingTestCase(BaseTestCase):
-    """test _do_search by itself and with multiple calls to handle_text."""
+    """Set up patches used by subclasses."""
     class_ui = gui.SearchBox
 
     @defer.inlineCallbacks
@@ -208,6 +208,9 @@ class SearchingTestCase(BaseTestCase):
         self.mock_load_items = self.load_items_patch.start()
         self.addCleanup(self.load_items_patch.stop)
 
+
+class DoSearchTestCase(SearchingTestCase):
+    """A subclass so that MultipleSearchingTestCase doesn't also call these."""
     @defer.inlineCallbacks
     def test_do_search_text_same(self):
         """If searchbox text same after search_files call, call load_items."""
@@ -231,11 +234,37 @@ class SearchingTestCase(BaseTestCase):
         yield d
         self.assertFalse(self.mock_load_items.called)
 
+
+class MultipleSearchingTestCase(SearchingTestCase):
+    """Test multiple fast calls to handle_text."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        # do all this before calling super, because ui._do_search is
+        # connected to a Qt signal in the __init__ of the ui class,
+        # and we need to connect our patched version:
+        self.do_search_ended = defer.DeferredQueue()
+        # save unbound function because self.ui won't exist yet:
+        self.orig_do_search = gui.SearchBox._do_search
+
+        @defer.inlineCallbacks
+        def do_search_later():
+            # call unbound function with now-existing self.ui:
+            yield self.orig_do_search(self.ui)
+            self.do_search_ended.put("done")
+
+        self.do_search_patch = patch.object(gui.SearchBox, '_do_search')
+        self.do_search_mock = self.do_search_patch.start()
+        self.do_search_mock.side_effect = do_search_later
+        self.addCleanup(self.do_search_patch.stop)
+
+        yield super(MultipleSearchingTestCase, self).setUp()
+
     @defer.inlineCallbacks
     def test_multiple_searches_while_waiting(self):
         """Only call load_items once despite multiple quick text changes."""
 
-        # This test checks the case not covered in other tests, where
+        # This test checks a case not covered earlier, where
         # text changes once, then the text changes again, after
         # _do_search is called but before search_files has returned.
 
@@ -243,48 +272,37 @@ class SearchingTestCase(BaseTestCase):
         # be called twice, but _load_items should only be called once,
         # by the last call to _do_search.
 
-        self.do_search_ended = defer.DeferredQueue()
-        self.orig_do_search = self.ui._do_search
+        # call once with original query
+        self.mock_text.return_value = 'query'
+        self.ui.handle_text_changed('query')
 
-        @defer.inlineCallbacks
-        def do_search_later():
-            yield self.orig_do_search()
-            self.do_search_ended.put("done")
+        # wait for the first delayed do_search call to call
+        # search_files and check its arg for good measure
+        search_files_query = yield self.search_files_started_q.get()
+        self.assertEqual('query', search_files_query)
 
-        with patch.object(self.ui, '_do_search') as mock_do_search:
-            mock_do_search.side_effect = do_search_later
+        # first call to search_files is paused waiting for
+        # search_files_done_q, simulating a long IPC call.
+        # the delayed call to do_search is no longer active.
 
-            # call once with original query
-            self.mock_text.return_value = 'query'
-            self.ui.handle_text_changed('query')
+        # while we wait for search_files, the user changes the
+        # query, scheduling a new delayed call to do_search:
+        self.mock_text.return_value = 'query2'
+        self.ui.handle_text_changed('query2')
 
-            # wait for the first delayed do_search call to call
-            # search_files and check its arg for good measure
-            search_files_query = yield self.search_files_started_q.get()
-            self.assertEqual('query', search_files_query)
+        # release both calls to search_files:
+        self.search_files_done_q.put(['result1'])
+        self.search_files_done_q.put(['result2'])
 
-            # first call to search_files is paused waiting for
-            # search_files_done_q, simulating a long IPC call.
-            # the delayed call to do_search is no longer active.
+        # wait for first delayed call to do_search to finish:
+        yield self.do_search_ended.get()
 
-            # while we wait for search_files, the user changes the
-            # query, scheduling a new delayed call to do_search:
-            self.mock_text.return_value = 'query2'
-            self.ui.handle_text_changed('query2')
-
-            # release both calls to search_files:
-            self.search_files_done_q.put(['result1'])
-            self.search_files_done_q.put(['result2'])
-
-            # wait for first delayed call to do_search to finish:
-            yield self.do_search_ended.get()
-
-            # check that the second call to search_files got the right
-            # text:
-            search_files_query = yield self.search_files_started_q.get()
-            self.assertEqual('query2', search_files_query)
-            # wait for second do_search to end
-            yield self.do_search_ended.get()
+        # check that the second call to search_files got the right
+        # text:
+        search_files_query = yield self.search_files_started_q.get()
+        self.assertEqual('query2', search_files_query)
+        # wait for second do_search to end
+        yield self.do_search_ended.get()
 
         # check that _load_items is only called once, and that it's
         # using only the results from the last call to search_files:
@@ -292,83 +310,6 @@ class SearchingTestCase(BaseTestCase):
         self.assertEqual(['result2'], self.ui.current_results)
 
 
-class TextChangedTestCase(BaseTestCase):
-    """Test handle_text_changed scheduling pending calls."""
-
-    class_ui = gui.SearchBox
-
-    @defer.inlineCallbacks
-    def setUp(self):
-        yield super(TextChangedTestCase, self).setUp()
-
-        # patch this way instead of using decorators because we need
-        # to patch self.ui.popup, which isn't defined yet when the
-        # decorators run.
-        self.qtreactor_patch = patch.object(gui.SearchBox, 'qtreactor')
-        self.mock_qtreactor = self.qtreactor_patch.start()
-        self.addCleanup(self.qtreactor_patch.stop)
-
-        self.popup_patch = patch.object(self.ui, 'popup')
-        self.mock_popup = self.popup_patch.start()
-        self.addCleanup(self.popup_patch.stop)
-
-    def test_empty_text_no_pending(self):
-        """arg='' with no pending call only hides the popup."""
-        self.ui.handle_text_changed('')
-        self.mock_popup.hide.assert_called_once_with()
-        self.assertFalse(self.mock_qtreactor.callLater.called)
-
-    def test_empty_text_with_pending(self):
-        """arg='' with a pending call hides the popup and cancels pending."""
-        with patch.object(self.ui, 'pending_call') as mock_pending_call:
-            mock_pending_call.active.return_value = True
-            self.ui.handle_text_changed('')
-            mock_pending_call.active.assert_called_once_with()
-            mock_pending_call.cancel.assert_called_once_with()
-        self.mock_popup.hide.assert_called_once_with()
-        self.assertFalse(self.mock_qtreactor.callLater.called)
-
-    def test_empty_text_with_inactive_pending(self):
-        """arg='' with a pending call hides the popup and cancels pending."""
-        with patch.object(self.ui, 'pending_call') as mock_pending_call:
-            mock_pending_call.active.return_value = False
-            self.ui.handle_text_changed('')
-            mock_pending_call.active.assert_called_once_with()
-            self.assertFalse(mock_pending_call.cancel.called)
-        self.mock_popup.hide.assert_called_once_with()
-        self.assertFalse(self.mock_qtreactor.callLater.called)
-
-    def test_nonempty_text_with_no_pending(self):
-        """arg='b' with no pending call schedules a call."""
-        self.ui.handle_text_changed('b')
-        self.assertEqual([call(0.1, self.ui._do_search)],
-                         self.mock_qtreactor.callLater.mock_calls)
-
-    def test_nonempty_text_with_inactive_pending(self):
-        """call an inactive (called already) call schedules another call."""
-        with patch.object(self.ui, 'pending_call') as mock_pending_call:
-            mock_pending_call.active.return_value = False
-            self.ui.handle_text_changed('b')
-            mock_pending_call.active.assert_called_once_with()
-            self.assertFalse(mock_pending_call.reset.called)
-
-        self.assertFalse(self.mock_popup.hide.called)
-
-        self.assertEqual([call(0.1, self.ui._do_search)],
-                         self.mock_qtreactor.callLater.mock_calls)
-
-    def test_nonempty_text_with_pending(self):
-        """arg='' with a pending call hides the popup and resets pending."""
-        with patch.object(self.ui, 'pending_call') as mock_pending_call:
-            mock_pending_call.active.return_value = True
-            self.ui.handle_text_changed('b')
-            mock_pending_call.active.assert_called_once_with()
-            mock_pending_call.reset.assert_called_once_with(0.1)
-
-        self.assertFalse(self.mock_popup.hide.called)
-        self.assertFalse(self.mock_qtreactor.callLater.called)
-
-
 class FileItemTestCase(BaseTestCase):
     """Test the File Item."""
 
