@@ -64,6 +64,11 @@ from ubuntuone.controlpanel.tests import (
     USER_HOME,
 )
 
+try:
+    from urllib.parse import quote
+except ImportError:
+    from urllib import quote
+
 SAMPLE_SIGNED = UBUNTUONE_FROM_OAUTH + '?oauth_nonce=' \
     '36886134&oauth_timestamp=1310671062&oauth_consumer_key=consumer_key&' \
     'oauth_signature_method=HMAC-SHA1&next=%2Fblah&oauth_version=1.0&' \
@@ -110,7 +115,7 @@ class MockWebClient(CallRecorder):
             return defer.succeed(result)
 
     @defer.inlineCallbacks
-    def build_signed_iri(self, iri, params):
+    def build_signed_iri(self, iri, params=None):
         """Fake the IRI signing."""
         creds = yield self.get_credentials()
         result = u'%s-%s-%s' % (iri, unicode(creds), unicode(params))
@@ -491,8 +496,9 @@ class SignIriTestCase(BackendBasicTestCase):
         iri = UBUNTUONE_LINK + 'foo'
         result = yield self.be.build_signed_iri(iri)
 
-        expected = yield self.be.wc.build_signed_iri(UBUNTUONE_FROM_OAUTH,
-                                                     {'next': iri})
+        expected_iri = UBUNTUONE_FROM_OAUTH + '?next=%s' % quote(iri, safe='')
+        expected = yield self.be.wc.build_signed_iri(expected_iri)
+
         self.assertEqual(expected, result)
 
 
