@@ -31,6 +31,11 @@ from ubuntu_sso.utils.webclient.common import (
 )
 from ubuntuone.platform.credentials import APP_NAME
 
+try:
+    from urllib.parse import quote
+except ImportError:
+    from urllib import quote
+
 
 SAMPLE_KEY = "result"
 SAMPLE_VALUE = "sample result"
@@ -163,8 +168,8 @@ class WebClientBuildSignedIriTestCase(WebClientTestCase):
     @defer.inlineCallbacks
     def test_correct_query(self):
         """Test the invariant parts of the signed URL."""
-        signed = yield self.wc.build_signed_iri(SAMPLE_TARGET,
-                                                params={'next': u'/blah'})
+        sign_iri = SAMPLE_TARGET + '?next=%s' % quote('/blah', safe='')
+        signed = yield self.wc.build_signed_iri(sign_iri)
         parsed_signed = urlparse(signed)
         parsed_sample = urlparse(SAMPLE_SIGNED)
         signed_query = parse_qs(parsed_signed.query)
@@ -178,8 +183,8 @@ class WebClientBuildSignedIriTestCase(WebClientTestCase):
     @defer.inlineCallbacks
     def test_url_with_query(self):
         """Test that we are using the right scheme."""
-        signed = yield self.wc.build_signed_iri(SAMPLE_TARGET,
-                                             params={'next': u'/blah?foo=bar'})
+        sign_iri = SAMPLE_TARGET + '?next=%s' % quote('/blah?foo=bar', safe='')
+        signed = yield self.wc.build_signed_iri(sign_iri)
         parsed_signed = urlparse(signed)
         signed_query = parse_qs(parsed_signed.query)
 
